% LQR Design & Param Initialization file init.m
d2r=pi/180; r2d=180/pi;
[Aps, Bps, Cps, Dps] = pitch_des;                % Load Pitch aero-surf Design Model
[Als, Bls, Cls, Dls] = later_des;                % Load Lateral aero-surf Design Model
[As, Bs, Cs, Ds] = vehicle_sim;                  % Simulation Model 6-dof
[Apu,Bpu,Cpu,Dpu]= pitch_unc;                    % Pitch Vehicle Model with Uncertainties
[Alu,Blu,Clu,Dlu]= later_unc;                    % Later Vehicle Model with Uncertainties
load KmixM0p4.mat -ascii; Kmix=KmixM0p4;         % Load Surfaces Mix Logic (7 x 4)

alfa0=8.531; V0=466.4; Thet0=-33.133; ge=32.174; % Additional Vehicle Parameters
calfa=cos(alfa0*d2r); salfa=sin(alfa0*d2r);      % for Body to Stability Transform

% Convert Lateral State Vector from Body to Stability Axes, Outputs=States
[Al4,Bl4,Cl4,Dl4]= linmod('Ldes5x');             % 5-state model {p,r,bet,pint,betint}
Al5= Cl4*Al4*inv(Cl4);  Bl5= Cl4*Bl4;            % Stability axis System
Cl5= Cl4*inv(Cl4);      Dl5= Dl4;

% Lateral LQR Design Using Only the RCS Jets
R=[1,10]*0.35; R=diag(R);                         % LQR Weights R=[1,1]*2
Q=[10 2 0.5 20 0.01]; Q=diag(Q);               % LQR Weights Q=[1 0.4 0.5 0.2 0.005]*3
[Kpr,s,e]=lqr(Al5,Bl5,Q,R)                       % Perform LQR design on Jets
save Kpr_M0p4_0.mat Kpr -ascii                   % Lateral State-Feedback Gain

% Pitch LQR Design Using the 7 Aero-Surfaces, States: {theta,q,alfa,dH,dV}
[Ap4,Bp4,Cp4,Dp4]= linmod('Pdes5x');             % Include Kmix in design model
R=[5,1]; R=diag(R);                              % Pitch LQR Contrl Weights 
Q=[0.00001 0.01 0.001 7 5]; Q=diag(Q);           % LQR State Weights {theta,q,alfa,dH,dV}
[Kq,s,e]=lqr(Ap4,Bp4,Q,R)                        % Perform LQR design on Surf
save Kq_M0p4_0.mat Kq -ascii                     % Longitudinal State-Feedback Gain

% Load Linear Sim Parameters
load THV.mat -ascii;                           
t=THV(:,1)'-THV(1,1); h=THV(:,2)'; v=THV(:,3)';
x0=[0 0 -2 -2 0 0 18 0 0 0]'*d2r;                  % State Initialization

