% File Init.m for Initialization and Perform Control Design
d2r=pi/180; r2d=180/pi;
[Aps, Bps, Cps, Dps] = pitch_des;                % Load Pitch Design Model
[Apa, Bpa, Cpa, Dpa] = pitch_anal;               % Load Pitch Analysis Model
[Als, Bls, Cls, Dls] = later_des;                % Load Lateral aero-surf Design Model
[Ave, Bve, Cve, Dve] = vehicle_sim;              % Simulation Model 6-dof
load KmixM4.mat -ascii; Kmix=KmixM4;             % Load Surfaces Mix Logic (7 x 3)

alfa0=10.4; V0=4278.9; Thet0=8.548; ge=32.174;   % Additional Vehicle Parameters
calfa=cos(alfa0*d2r); salfa=sin(alfa0*d2r);      % for Body to Stability Transform

% Convert Lateral State Vector from Body to Stability Axes, Outputs=States
[Al4,Bl4,Cl4,Dl4]= linmod('Ldes5x');             % 5-state model {p,r,bet,pint,betint}
Al5= Cl4*Al4*inv(Cl4);  Bl5= Cl4*Bl4;            % Stability axis System
Cl5= Cl4*inv(Cl4);      Dl5= Dl4;

% Lateral LQR Design Using Only the RCS Jets
R=[1,10]*0.4; R=diag(R);                          % LQR Weights R=[1,1]*2
Q=[10 2 0.5 10 0.01]*1; Q=diag(Q);               % LQR Weights Q=[1 0.4 0.5 0.2 0.005]*3
[Kpr,s,e]=lqr(Al5,Bl5,Q,R)                       % Perform LQR design on Jets
save Kpr_M04_0.mat Kpr -ascii

% Pitch LQR Design Using the 7 Aero-Surfaces, States: {theta,q,alfa,alfi}
[Ap4,Bp4,Cp4,Dp4]= linmod('Pdes4x');             % 4-state des model {theta,q,alfa,alfi}
R=4; Q=[0.001 0.2 10  10]; Q=diag(Q);                 % LQR Weights {theta,q,alfa,alfi}
[Kq,s,e]=lqr(Ap4,Bp4,Q,R)                        % Perform LQR design on Surf
save Kq_M04_0.mat Kq -ascii
