d2r=pi/180; r2d=180/pi;
[Aps, Bps, Cps, Dps] = pitch_des;                % Load Pitch aero-surf Design Model
[Als, Bls, Cls, Dls] = later_des;                % Load Lateral aero-surf Design Model
[Ave, Bve, Cve, Dve] = vehicle_sim;              % Simulation Model 6-dof
load KmixM5.mat -ascii; Kmix=KmixM5;             % Load Surfaces Mix Logic (7 x 3)

alfa0=10.625; V0=5321; Thet0=9.323; ge=32.174;   % Additional Vehicle Parameters
calfa=cos(alfa0*d2r); salfa=sin(alfa0*d2r);      % for Body to Stability Transform

% Convert Lateral State Vector from Body to Stability Axes, Outputs=States
[Al4,Bl4,Cl4,Dl4]= linmod('Ldes5x');             % 5-state model {p,r,bet,pint,betint}
Al5= Cl4*Al4*inv(Cl4);  Bl5= Cl4*Bl4;            % Stability axis System
Cl5= Cl4*inv(Cl4);      Dl5= Dl4;

% Lateral LQR Design Using Only the RCS Jets
R=[1,10]*0.5; R=diag(R);                           % CS LQR Weights R=[1,10]*2
Q=[10 0.4 0.5 10 0.005]*3; Q=diag(Q);               % CS LQR Weights Q=[1 1 1 0.04 0.04]*0.4
[Kpr,s,e]=lqr(Al5,Bl5,Q,R)                       % Perform LQR design on Jets
save Kpr_M05_0.mat Kpr -ascii

% Alpha Control LQR Design, States: {theta,q,alfa,alf_int}
[Ap4,Bp4,Cp4,Dp4]= linmod('Pdes4xb');             % 4-state des model {theta,q,alfa,alfi}
R=0.4; Q=[0.0001 0.5 60 50]; Q=diag(Q);            % LQR Weights {theta,q,alfa,alfi}
[Kq,s,e]=lqr(Ap4,Bp4,Q,R)                        % Perform LQR design on Surf
save Kq_M05_b.mat Kq -ascii

% Gamma Control LQR Design, States: {gamm_int, gamma, q,alfa}
[Ap4,Bp4,Cp4,Dp4]= linmod('Pdes4x');             % 4-state des model {gami,gama,q,alfa}
Ap5= Cp4*Ap4*inv(Cp4); Bp5= Cp4*Bp4;             % Convert to Output=State={gami,gama,q,alfa}
Cp5= Cp4*inv(Cp4);     Dp5= Dp4;
R=0.5; Q=[1  1  2  0.5]; Q=diag(Q);              % LQR Weights {gami,gama,q,alfa}
[Kq,s,e]=lqr(Ap5,Bp5,Q,R)                        % Perform LQR design on Surf
save Kq_M05_a.mat Kq -ascii
