% Initialization for the Lifting-Body Aircraft Non-Linear 6-dof Simulation
global Kq Kpr d2r r2d Kmix Klmix
d2r=pi/180; r2d=180/pi;
mass=528.0;
inertia=[10800, 0, 433; 0, 43300, 0; 433, 0, 49600];
h0=250000.0; x0=0; a0=29.4; gm0=-1.3; th0=a0+gm0;                      % 
Euler_0=[0, th0, 0]*d2r;                              % Initial Attitude
pqr_0=[0,0,0];                                        % Init Body rates
Uvw_0=[cosd(a0),0,sind(a0)]*24800;                    % U,V,W (ft/sec)
x_cg=-17.04; y_cg=0;  z_cg=-2.03;                     % CG
x_ref=-16.2; y_ref=0; z_ref=-2.1;                     % MRC
Sref=300; ch=34.0; sp=15;
Nmch=15; Nalf=33; Nbet=3;                             % Numbers in Aero Data

% Load Aero Data for the Base Vehicle and the 7 Aero-Surfaces
[CX,CY,CZ,Cl,Cm,Cn]            = Base_Aero_Coeff;                                
[CXd1,CYd1,CZd1,Cld1,Cmd1,Cnd1]= Left_Elevon;
[CXd2,CYd2,CZd2,Cld2,Cmd2,Cnd2]= Right_Elevon;
[CXd3,CYd3,CZd3,Cld3,Cmd3,Cnd3]= Vert_Rudder;
[CXd4,CYd4,CZd4,Cld4,Cmd4,Cnd4]= BFlap_UprLft;
[CXd5,CYd5,CZd5,Cld5,Cmd5,Cnd5]= BFlap_UprRht;
[CXd6,CYd6,CZd6,Cld6,Cmd6,Cnd6]= BFlap_LowLft;
[CXd7,CYd7,CZd7,Cld7,Cmd7,Cnd7]= BFlap_LowRht;

% Define Machs, Alphas, Betas, and Surface deflect angles
Machs=[0.1,0.3,0.6,0.8,0.9,0.95,1.1,1.2,1.6,2.0,2.5,3.0,3.5,4.0,5.0];
Betas=[-5, 0, 5];
for i=1:33; Alfas(i)=i-3; end
Deltas1=[-30,-15,0,15,30]; Deltas2=Deltas1; Deltas3=Deltas1;
Deltas4=[-60,-45,-30,-15,0]; Deltas5=Deltas4;
Deltas6=[0, 15, 30, 45, 60]; Deltas7=Deltas6;

load FCS_Gains                            % Flight Control LQR gain designs
load THV -ascii                           % altitude velocity vs time commands
load KmixM0p4 -ascii                      % surface mixing matrix near landing
